==> aesudoku_0.5.jar: org/parg/azureus/plugins/sudoku/SudokuPlugin.java <==
/*
 * Created on 04-Sep-2005
 * Created by Paul Gardner
 * Copyright (C) 2005 Aelitis, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * AELITIS, SARL au capital de 30,000 euros
 * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
 *
 */

package org.parg.azureus.plugins.sudoku;

import org.gudy.azureus2.plugins.PluginInterface;
import org.gudy.azureus2.plugins.UnloadablePlugin;
import org.gudy.azureus2.plugins.ui.UIInstance;
import org.gudy.azureus2.plugins.ui.UIManagerListener;
import org.gudy.azureus2.plugins.utils.LocaleUtilities;
import org.gudy.azureus2.ui.swt.plugins.UISWTInstance;
import org.parg.azureus.plugins.sudoku.model.SudokuModel;
import org.parg.azureus.plugins.sudoku.model.SudokuModelFactory;
import org.parg.azureus.plugins.sudoku.ui.swt.SudokuUISWT;

public class 
SudokuPlugin
	implements UnloadablePlugin
{	
	private SudokuUISWT		swt_ui;
	
	public
	SudokuPlugin()
	{
	}
	
	public void
	initialize(
		PluginInterface		plugin_interface )
	{
		LocaleUtilities loc_utils = plugin_interface.getUtilities().getLocaleUtilities();

		loc_utils.integrateLocalisedMessageBundle( "org.parg.azureus.plugins.sudoku.internat.Messages" );

		plugin_interface.getUIManager().addUIListener(
			new UIManagerListener()
			{
				public void
				UIAttached(
					UIInstance		instance )
				{
					if ( instance instanceof UISWTInstance ){
						
						UISWTInstance	swt = (UISWTInstance)instance;
						
						SudokuModel model = SudokuModelFactory.create();

						swt_ui = new SudokuUISWT( model, swt );
					}
				}
				
				public void
				UIDetached(
					UIInstance		instance )
				{
					
				}
			});
	}
	
	public void
	unload()
	{
		if ( swt_ui != null ){
			
			swt_ui.destroy();
		}
	}
}

==> aesudoku_0.5.1.jar: org/parg/azureus/plugins/sudoku/SudokuPlugin.java <==
/*
 * Created on 04-Sep-2005
 * Created by Paul Gardner
 * Copyright (C) 2005 Aelitis, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * AELITIS, SARL au capital de 30,000 euros
 * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
 *
 */

package org.parg.azureus.plugins.sudoku;

import java.io.File;

import org.gudy.azureus2.core3.util.Debug;
import org.gudy.azureus2.plugins.PluginInterface;
import org.gudy.azureus2.plugins.PluginListener;
import org.gudy.azureus2.plugins.UnloadablePlugin;
import org.gudy.azureus2.plugins.ui.UIInstance;
import org.gudy.azureus2.plugins.ui.UIManagerListener;
import org.gudy.azureus2.plugins.utils.LocaleUtilities;
import org.gudy.azureus2.ui.swt.plugins.UISWTInstance;
import org.parg.azureus.plugins.sudoku.model.SudokuModel;
import org.parg.azureus.plugins.sudoku.model.SudokuModelFactory;
import org.parg.azureus.plugins.sudoku.ui.swt.SudokuUISWT;

public class 
SudokuPlugin
	implements UnloadablePlugin
{	
	private static final String	TMP_SAVE_FILE = "current.sud";
	
	
	private volatile PluginInterface	plugin_interface;
	
	private volatile SudokuUISWT		swt_ui;
	private volatile SudokuModel 		model;
	
	
	public
	SudokuPlugin()
	{
	}
	
	public void
	initialize(
		PluginInterface		_plugin_interface )
	{
		plugin_interface	= _plugin_interface;
		
		LocaleUtilities loc_utils = plugin_interface.getUtilities().getLocaleUtilities();

		loc_utils.integrateLocalisedMessageBundle( "org.parg.azureus.plugins.sudoku.internat.Messages" );

		plugin_interface.getUIManager().addUIListener(
			new UIManagerListener()
			{
				public void
				UIAttached(
					UIInstance		instance )
				{
					if ( instance instanceof UISWTInstance ){
						
						UISWTInstance	swt = (UISWTInstance)instance;
						
						model = SudokuModelFactory.create();

						File f = plugin_interface.getPluginconfig().getPluginUserFile( TMP_SAVE_FILE );
						
						if ( f.exists()){
							
							try{
								model.importValues( f );
								
							}catch( Throwable e ){
								
								Debug.out( e );
							}
						}
						
						swt_ui = new SudokuUISWT( model, swt );
					}
				}
				
				public void
				UIDetached(
					UIInstance		instance )
				{
					
				}
			});
		
		plugin_interface.addListener(
			new PluginListener()
			{
				public void
				initializationComplete()
				{
				}
				
				public void
				closedownInitiated()
				{
					save();
				}
				
				public void
				closedownComplete()
				{
				}
			});
	}
	
	public void
	unload()
	{
		save();
		
		if ( swt_ui != null ){
			
			swt_ui.destroy();
			
			swt_ui = null;
		}
		

		model				= null;
		plugin_interface	= null;
	}
	
	private void
	save()
	{
		if ( plugin_interface != null && model != null ){
			
			File f = plugin_interface.getPluginconfig().getPluginUserFile( TMP_SAVE_FILE );
			
			try{
				model.exportValues( f );
								
			}catch( Throwable e ){
				
				Debug.out( e );
			}
		}
	}
}
